summaryrefslogtreecommitdiffstats
path: root/chalk/ui/kis_view.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:02:43 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:02:43 -0600
commitaea627236e4de24599c3e30617cf264c3c1b7d40 (patch)
tree467e13ca5a7eb0ab292259289ecc3572f53c5eae /chalk/ui/kis_view.cc
parent786304c6211f35ddc4cdd54b7aa7985fef4a2e70 (diff)
downloadkoffice-aea627236e4de24599c3e30617cf264c3c1b7d40.tar.gz
koffice-aea627236e4de24599c3e30617cf264c3c1b7d40.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'chalk/ui/kis_view.cc')
-rw-r--r--chalk/ui/kis_view.cc68
1 files changed, 34 insertions, 34 deletions
diff --git a/chalk/ui/kis_view.cc b/chalk/ui/kis_view.cc
index 6c8303d7..357be9d2 100644
--- a/chalk/ui/kis_view.cc
+++ b/chalk/ui/kis_view.cc
@@ -362,7 +362,7 @@ KisView::~KisView()
static TQt::Dock stringToDock( const TQString& attrPosition )
{
- KToolBar::Dock dock = KToolBar::DockTop;
+ TDEToolBar::Dock dock = TDEToolBar::DockTop;
if ( !attrPosition.isEmpty() ) {
if ( attrPosition == "top" )
dock = TQt::DockTop;
@@ -603,83 +603,83 @@ void KisView::setupActions()
m_fullScreen = KStdAction::fullScreen( NULL, NULL, actionCollection(), this );
connect( m_fullScreen, TQT_SIGNAL( toggled( bool )), TQT_TQOBJECT(this), TQT_SLOT( slotUpdateFullScreen( bool )));
- m_imgProperties = new KAction(i18n("Image Properties"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotImageProperties()), actionCollection(), "img_properties");
- m_imgScan = 0; // How the hell do I get a KAction to the scan plug-in?!?
- m_imgResizeToLayer = new KAction(i18n("Resize Image to Size of Current Layer"), 0, TQT_TQOBJECT(this), TQT_SLOT(imgResizeToActiveLayer()), actionCollection(), "resizeimgtolayer");
+ m_imgProperties = new TDEAction(i18n("Image Properties"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotImageProperties()), actionCollection(), "img_properties");
+ m_imgScan = 0; // How the hell do I get a TDEAction to the scan plug-in?!?
+ m_imgResizeToLayer = new TDEAction(i18n("Resize Image to Size of Current Layer"), 0, TQT_TQOBJECT(this), TQT_SLOT(imgResizeToActiveLayer()), actionCollection(), "resizeimgtolayer");
// view actions
m_zoomIn = KStdAction::zoomIn(TQT_TQOBJECT(this), TQT_SLOT(slotZoomIn()), actionCollection(), "zoom_in");
m_zoomOut = KStdAction::zoomOut(TQT_TQOBJECT(this), TQT_SLOT(slotZoomOut()), actionCollection(), "zoom_out");
- m_actualPixels = new KAction(i18n("Actual Pixels"), "Ctrl+0", TQT_TQOBJECT(this), TQT_SLOT(slotActualPixels()), actionCollection(), "actual_pixels");
+ m_actualPixels = new TDEAction(i18n("Actual Pixels"), "Ctrl+0", TQT_TQOBJECT(this), TQT_SLOT(slotActualPixels()), actionCollection(), "actual_pixels");
m_actualSize = KStdAction::actualSize(TQT_TQOBJECT(this), TQT_SLOT(slotActualSize()), actionCollection(), "actual_size");
m_actualSize->setEnabled(false);
m_fitToCanvas = KStdAction::fitToPage(TQT_TQOBJECT(this), TQT_SLOT(slotFitToCanvas()), actionCollection(), "fit_to_canvas");
// layer actions
- m_layerAdd = new KAction(i18n("&Add..."), "Ctrl+Shift+N", TQT_TQOBJECT(this), TQT_SLOT(layerAdd()), actionCollection(), "insert_layer");
+ m_layerAdd = new TDEAction(i18n("&Add..."), "Ctrl+Shift+N", TQT_TQOBJECT(this), TQT_SLOT(layerAdd()), actionCollection(), "insert_layer");
m_actionPartLayer = new KoPartSelectAction( i18n( "&Object Layer" ), "frame_query",
TQT_TQOBJECT(this), TQT_SLOT( addPartLayer() ),
actionCollection(), "insert_part_layer" );
- m_actionAdjustmentLayer = new KAction( i18n( "&Adjustment Layer" ), 0,
+ m_actionAdjustmentLayer = new TDEAction( i18n( "&Adjustment Layer" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( addAdjustmentLayer() ),
actionCollection(), "insert_adjustment_layer" );
- m_layerRm = new KAction(i18n("&Remove"), 0, TQT_TQOBJECT(this), TQT_SLOT(layerRemove()), actionCollection(), "remove_layer");
- m_layerDup = new KAction(i18n("Duplicate"), 0, TQT_TQOBJECT(this), TQT_SLOT(layerDuplicate()), actionCollection(), "duplicate_layer");
- m_layerHide = new KToggleAction(i18n("&Hide"), 0, TQT_TQOBJECT(this), TQT_SLOT(layerToggleVisible()), actionCollection(), "hide_layer");
+ m_layerRm = new TDEAction(i18n("&Remove"), 0, TQT_TQOBJECT(this), TQT_SLOT(layerRemove()), actionCollection(), "remove_layer");
+ m_layerDup = new TDEAction(i18n("Duplicate"), 0, TQT_TQOBJECT(this), TQT_SLOT(layerDuplicate()), actionCollection(), "duplicate_layer");
+ m_layerHide = new TDEToggleAction(i18n("&Hide"), 0, TQT_TQOBJECT(this), TQT_SLOT(layerToggleVisible()), actionCollection(), "hide_layer");
m_layerHide->setCheckedState(KGuiItem(i18n("&Show")));
m_layerHide->setChecked(false);
- m_layerRaise = new KAction(i18n("Raise"), "raise", "Ctrl+]", TQT_TQOBJECT(this), TQT_SLOT(layerRaise()), actionCollection(), "raiselayer");
- m_layerLower = new KAction(i18n("Lower"), "lower", "Ctrl+[", TQT_TQOBJECT(this), TQT_SLOT(layerLower()), actionCollection(), "lowerlayer");
- m_layerTop = new KAction(i18n("To Top"), "bring_forward", "Ctrl+Shift+]", TQT_TQOBJECT(this), TQT_SLOT(layerFront()), actionCollection(), "toplayer");
- m_layerBottom = new KAction(i18n("To Bottom"), "send_backward", "Ctrl+Shift+[", TQT_TQOBJECT(this), TQT_SLOT(layerBack()), actionCollection(), "bottomlayer");
- m_layerProperties = new KAction(i18n("Properties"), 0, TQT_TQOBJECT(this), TQT_SLOT(layerProperties()), actionCollection(), "layer_properties");
- (void)new KAction(i18n("I&nsert Image as Layer..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotInsertImageAsLayer()), actionCollection(), "insert_image_as_layer");
- m_layerSaveAs = new KAction(i18n("Save Layer as Image..."), "filesave", TQT_TQOBJECT(this), TQT_SLOT(saveLayerAsImage()), actionCollection(), "save_layer_as_image");
- (void)new KAction(i18n("Flip on &X Axis"), "view_left_right", 0, TQT_TQOBJECT(this), TQT_SLOT(mirrorLayerX()), actionCollection(), "mirrorLayerX");
- (void)new KAction(i18n("Flip on &Y Axis"), "view_top_bottom", 0, TQT_TQOBJECT(this), TQT_SLOT(mirrorLayerY()), actionCollection(), "mirrorLayerY");
-
- m_createMask = new KAction(i18n("Create Mask"), 0, TQT_TQOBJECT(this),
+ m_layerRaise = new TDEAction(i18n("Raise"), "raise", "Ctrl+]", TQT_TQOBJECT(this), TQT_SLOT(layerRaise()), actionCollection(), "raiselayer");
+ m_layerLower = new TDEAction(i18n("Lower"), "lower", "Ctrl+[", TQT_TQOBJECT(this), TQT_SLOT(layerLower()), actionCollection(), "lowerlayer");
+ m_layerTop = new TDEAction(i18n("To Top"), "bring_forward", "Ctrl+Shift+]", TQT_TQOBJECT(this), TQT_SLOT(layerFront()), actionCollection(), "toplayer");
+ m_layerBottom = new TDEAction(i18n("To Bottom"), "send_backward", "Ctrl+Shift+[", TQT_TQOBJECT(this), TQT_SLOT(layerBack()), actionCollection(), "bottomlayer");
+ m_layerProperties = new TDEAction(i18n("Properties"), 0, TQT_TQOBJECT(this), TQT_SLOT(layerProperties()), actionCollection(), "layer_properties");
+ (void)new TDEAction(i18n("I&nsert Image as Layer..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotInsertImageAsLayer()), actionCollection(), "insert_image_as_layer");
+ m_layerSaveAs = new TDEAction(i18n("Save Layer as Image..."), "filesave", TQT_TQOBJECT(this), TQT_SLOT(saveLayerAsImage()), actionCollection(), "save_layer_as_image");
+ (void)new TDEAction(i18n("Flip on &X Axis"), "view_left_right", 0, TQT_TQOBJECT(this), TQT_SLOT(mirrorLayerX()), actionCollection(), "mirrorLayerX");
+ (void)new TDEAction(i18n("Flip on &Y Axis"), "view_top_bottom", 0, TQT_TQOBJECT(this), TQT_SLOT(mirrorLayerY()), actionCollection(), "mirrorLayerY");
+
+ m_createMask = new TDEAction(i18n("Create Mask"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotCreateMask()), actionCollection(), "create_mask");
- m_maskFromSelection = new KAction(i18n("Mask From Selection"), 0, TQT_TQOBJECT(this),
+ m_maskFromSelection = new TDEAction(i18n("Mask From Selection"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotMaskFromSelection()), actionCollection(),
"mask_fromsel");
- m_maskToSelection = new KAction(i18n("Mask to Selection"), 0, TQT_TQOBJECT(this),
+ m_maskToSelection = new TDEAction(i18n("Mask to Selection"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotMaskToSelection()), actionCollection(), "mask_tosel");
- m_applyMask = new KAction(i18n("Apply Mask"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotApplyMask()),
+ m_applyMask = new TDEAction(i18n("Apply Mask"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotApplyMask()),
actionCollection(), "apply_mask");
- m_removeMask = new KAction(i18n("Remove Mask"), 0, TQT_TQOBJECT(this),
+ m_removeMask = new TDEAction(i18n("Remove Mask"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotRemoveMask()), actionCollection(), "remove_mask");
- m_showMask = new KToggleAction(i18n( "Show Mask" ), 0, TQT_TQOBJECT(this),
+ m_showMask = new TDEToggleAction(i18n( "Show Mask" ), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotShowMask()), actionCollection(), "show_mask");
- m_editMask = new KToggleAction(i18n( "Edit Mask" ), 0, TQT_TQOBJECT(this),
+ m_editMask = new TDEToggleAction(i18n( "Edit Mask" ), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotEditMask()), actionCollection(), "edit_mask");
// image actions
- m_imgFlatten = new KAction(i18n("&Flatten Image"), "Ctrl+Shift+E", TQT_TQOBJECT(this), TQT_SLOT(flattenImage()), actionCollection(), "flatten_image");
- m_imgMergeLayer = new KAction(i18n("&Merge with Layer Below"), "Ctrl+E", TQT_TQOBJECT(this), TQT_SLOT(mergeLayer()), actionCollection(), "merge_layer");
+ m_imgFlatten = new TDEAction(i18n("&Flatten Image"), "Ctrl+Shift+E", TQT_TQOBJECT(this), TQT_SLOT(flattenImage()), actionCollection(), "flatten_image");
+ m_imgMergeLayer = new TDEAction(i18n("&Merge with Layer Below"), "Ctrl+E", TQT_TQOBJECT(this), TQT_SLOT(mergeLayer()), actionCollection(), "merge_layer");
// setting actions
KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(preferences()), actionCollection(), "preferences");
- m_RulerAction = new KToggleAction( i18n( "Show Rulers" ), "Ctrl+R", TQT_TQOBJECT(this), TQT_SLOT( showRuler() ), actionCollection(), "view_ruler" );
+ m_RulerAction = new TDEToggleAction( i18n( "Show Rulers" ), "Ctrl+R", TQT_TQOBJECT(this), TQT_SLOT( showRuler() ), actionCollection(), "view_ruler" );
m_RulerAction->setChecked(cfg.showRulers());
m_RulerAction->setCheckedState(i18n("Hide Rulers"));
m_RulerAction->setWhatsThis( i18n("The rulers show the horizontal and vertical positions of the mouse on the image "
"and can be used to position your mouse at the right place on the canvas. <p>Uncheck this to disable "
"the rulers from being displayed." ) );
- //m_guideAction = new KToggleAction( i18n( "Guide Lines" ), 0, TQT_TQOBJECT(this), TQT_SLOT( viewGuideLines() ), actionCollection(), "view_guidelines" );
+ //m_guideAction = new TDEToggleAction( i18n( "Guide Lines" ), 0, TQT_TQOBJECT(this), TQT_SLOT( viewGuideLines() ), actionCollection(), "view_guidelines" );
// Add new palette
- new KAction(i18n("Add New Palette..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotAddPalette()),
+ new TDEAction(i18n("Add New Palette..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotAddPalette()),
actionCollection(), "add_palette");
- new KAction(i18n("Edit Palette..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotEditPalette()),
+ new TDEAction(i18n("Edit Palette..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotEditPalette()),
actionCollection(), "edit_palette");
// XXX: This triggers a repaint of the image, but way too early
@@ -2569,7 +2569,7 @@ void KisView::canvasGotDropEvent(TQDropEvent *event)
cancelId
};
- KPopupMenu popup(this, "drop_popup");
+ TDEPopupMenu popup(this, "drop_popup");
if (urls.count() == 1) {
if (currentImg() != 0) {